/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2012-2014 WaBit Inc. All rights reserved.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.wabit.uecs;


/**
 * CCMサービスの動作イベントリスナーです。
 *
 * @author WaBit
 *
 */
public interface ICcmServiceListener {

    /**
     * CCM値が送信された場合に起動されます。
     *
     * @param source イベント発生元サービス
     * @param value 送信されたCCMインスタンス
     */
    public void ccmSent(CcmService source, Ccm value);

    /**
     * CCM値が受信された場合に起動されます。
     *
     * @param source イベント発生元サービス
     * @param value 受信されたCCMインスタンス
     */
    public void ccmReceived(CcmService source, Ccm value);

    /**
     * CCM値が変更された場合に起動されます。
     *
     * @param source イベント発生元サービス
     * @param value 変更されたCCMインスタンス
     */
    public void ccmValueChanged(CcmService source, Ccm value);

    /**
     * CCMの有効期限が切れた場合に起動されます。
     *
     * @param source イベント発生元サービス
     * @param value 期限切れしたCCMインスタンス
     */
    public void ccmExpired(CcmService source, Ccm value);

}
